jgtpy
====

JGTPyIndicators Prep Service


Installation
------------

::

    pip install -U jgtpy

Example
-------

::


    >>> import pandas as pd
    >>> import jgtpy 
    >>> df=jgtpy.getPH('EUR/USD','H4')

